# eric7.WebBrowser.Network.SslErrorExceptionsDialog

Module implementing a dialog to edit the SSL error exceptions.

### Global Attributes

None

### Classes

SslErrorExceptionsDialog | Class implementing a dialog to edit the SSL error exceptions.

### Functions

None

## SslErrorExceptionsDialog

Class implementing a dialog to edit the SSL error exceptions.

### Derived from

QDialog, Ui_SslErrorExceptionsDialog

### Class Attributes

None

### Class Methods

None

### Methods

SslErrorExceptionsDialog | Constructor
__setRemoveButtons | Private method to set the state of the 'remove' buttons.
getSslErrorExceptions | Public method to retrieve the list of SSL error exceptions.
on_errorsTree_customContextMenuRequested | Private slot to show the context menu.
on_errorsTree_itemSelectionChanged | Private slot handling the selection of entries.
on_removeAllButton_clicked | Private slot to remove all entries.
on_removeButton_clicked | Private slot to remove the selected items.

### Static Methods

None

#### SslErrorExceptionsDialog (Constructor)

SslErrorExceptionsDialog(errorsDict, parent=None)

Constructor

errorsDict (dict of list of int)
  error exceptions
parent (QWidget)
  reference to the parent widget

#### SslErrorExceptionsDialog.__setRemoveButtons

__setRemoveButtons()

Private method to set the state of the 'remove' buttons.

#### SslErrorExceptionsDialog.getSslErrorExceptions

getSslErrorExceptions()

Public method to retrieve the list of SSL error exceptions.

Return:
  error exceptions

Return Type:
  dict of list of int

#### SslErrorExceptionsDialog.on_errorsTree_customContextMenuRequested

on_errorsTree_customContextMenuRequested(pos)

Private slot to show the context menu.

pos (QPoint)
  cursor position

#### SslErrorExceptionsDialog.on_errorsTree_itemSelectionChanged

on_errorsTree_itemSelectionChanged()

Private slot handling the selection of entries.

#### SslErrorExceptionsDialog.on_removeAllButton_clicked

on_removeAllButton_clicked()

Private slot to remove all entries.

#### SslErrorExceptionsDialog.on_removeButton_clicked

on_removeButton_clicked()

Private slot to remove the selected items.

Up